package com.xylink.sdk.test;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.CallInviteRequest;
import com.xylink.model.DeviceInfo;
import com.xylink.model.MeetingStatus;
import com.xylink.model.RecordingResponse;
import com.xylink.model.RecordingStopResponse;
import com.xylink.model.VodInfo;
import com.xylink.sdk.conferenceControl.ConferenceControlApi;
import com.xylink.sdk.recordingControl.RecordingControlApi;
import com.xylink.sdk.vod.VodApi;
import com.xylink.util.Result;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.fail;

/**
 * Created by wenya on 17/9/25.
 */
public class RecordingTest {

    private String enterpriseid = TestConfig.getInstance().getEnterpriseId();
    private String token = TestConfig.getInstance().getToken();
    private String callNumber = "";

    @BeforeClass
    public static void setup() {
//        SDKConfigMgr.setServerHost("http://172.18.160.51:8080");
        SDKConfigMgr.setServerHost("http://127.0.0.1:8081");
//        SDKConfigMgr.setServerHost("https://testdevsdk.xylink.com");
    }

    // TODO 注意：会议号必须有效，且已经有人加入才可录制
    @Test
    public void testStartRecord() {
        callNumber = "910067892539";

        RecordingControlApi recordingControlApi = new RecordingControlApi();
        try {
            Result result = recordingControlApi.startRecording(TestConfig.getInstance().getEnterpriseId(),
                    TestConfig.getInstance().getToken(), callNumber);
            System.out.println("开始录制结果：" + result);
            Assert.assertEquals(200, result.getErrorStatus());
            try {
                Thread.sleep(10000);
            } catch (InterruptedException e) {
            }
            Result<RecordingResponse> recordingResponseResult = recordingControlApi.stopRecording(TestConfig.getInstance().getEnterpriseId(),
                    TestConfig.getInstance().getToken(), callNumber);
            System.out.println("停止录制的结果：" + recordingResponseResult);
        } catch (IOException e) {
            fail(e.getMessage());
        }

        // 结束会议
        end();
    }

    // 查看会议状态 TODO 会议号必须有效
    @Test
    public void getMeetingStatus() {
        callNumber = "910075217386";
        ConferenceControlApi cca = new ConferenceControlApi();
        try {
            Result<MeetingStatus> result = cca.getMeetingStatus(enterpriseid, token, callNumber);
            System.out.println(result);
        } catch (IOException e) {
            fail(e.getMessage());
        }
    }

    // 邀请入会 TODO 会议号必须有效，邀请入会的设备号必须也有效，且在自己的企业下
    @Test
    public void inviteCall() {
        callNumber = "910075217386";

        ConferenceControlApi cca = new ConferenceControlApi();
        CallInviteRequest callInviteRequest = new CallInviteRequest();
        List<DeviceInfo> devices = new ArrayList<DeviceInfo>();
        DeviceInfo device = new DeviceInfo();
        device.setNumber("782165");
        devices.add(device);
        callInviteRequest.setCallNumber(callNumber);
        callInviteRequest.setDeviceList(devices);

        try {
            Result result = cca.inviteCall(enterpriseid, token, callInviteRequest);
            System.out.println(result);
        } catch (IOException e) {
            fail(e.getMessage());
        }
    }

    // 结束会议
    private void end() {
        ConferenceControlApi cca = new ConferenceControlApi();
        try {
            Result result = cca.end(enterpriseid, token, callNumber);
            System.out.println("结束会议：" + result);
        } catch (IOException e) {
            System.out.println("testEnd--" + e);
        }
    }

    @Test
    public void stopRecording() throws IOException {
        RecordingControlApi recordingControlApi = new RecordingControlApi();
        Result<RecordingResponse> result = recordingControlApi.stopRecording(TestConfig.getInstance().getEnterpriseId(),
                TestConfig.getInstance().getToken(), callNumber);
        System.out.println(result);
    }

    @Test
    public void stopRecordingWithSessionId() throws IOException {
        RecordingControlApi recordingControlApi = new RecordingControlApi();
        Result<RecordingStopResponse> result = recordingControlApi.stopRecordingWithSessionId(TestConfig.getInstance().getEnterpriseId(),
                TestConfig.getInstance().getToken(), callNumber);
        System.out.println(result);
    }

    @Test
    public void getMeetingRoomVods() throws IOException {
        callNumber = "910087494369";
        VodApi vodApi = new VodApi();
        Result<VodInfo[]> result = vodApi.getMeetingRoomVods(enterpriseid, token, callNumber, null, null);
        System.out.println(result);
    }

    @Test
    public void getDownloadurlBySessionId() throws IOException {
        String sessionId = "1643953";
        VodApi vodApi = new VodApi();
        Result result = vodApi.getDownloadurlBySessionId(enterpriseid, token, sessionId);
        System.out.println(result);
    }

    @Test
    public void getVods() throws IOException {
        enterpriseid = "f3c422a7c36eac6c924ed2a50eb4f49f82b128de";
        token = "a727338bb95fb608dde30774a96ae712c4a71ab3a4d6b499282048852bfe5a43";
        long startTime = 1564246414000l;
        long endTime = 1564329214000l;
        VodApi vodApi = new VodApi();
        System.out.println(new ObjectMapper().writeValueAsString(vodApi.getVods(enterpriseid,token,startTime,endTime)));

    }

    @Test
    public void getNemoDeviceVodsPage() throws IOException {
        enterpriseid = "40260e9046bae2da238ac0b0c572326b91726a83";
        token = "91c648e1df1bfa9d9c879c408d7583dfb7c353cadf8e15ad64031fe9a8cde098";
        VodApi vodApi = new VodApi();
        System.out.println(vodApi.getNemoDeviceVodsPage(enterpriseid,token,"300345619",0,99999999999999l,0,20));

    }
    @Test
    public void getMeetingRoomVodsPage() throws IOException {
        enterpriseid = "40260e9046bae2da238ac0b0c572326b91726a83";
        token = "91c648e1df1bfa9d9c879c408d7583dfb7c353cadf8e15ad64031fe9a8cde098";
        VodApi vodApi = new VodApi();
        System.out.println(vodApi.getMeetingRoomVodsPage(enterpriseid,token,"987987",0,99999999999999l,0,20));

    }

    @Test
    public void getVodsByLiveId() throws IOException {
        enterpriseid = "40260e9046bae2da238ac0b0c572326b91726a83";
        token = "91c648e1df1bfa9d9c879c408d7583dfb7c353cadf8e15ad64031fe9a8cde098";
        VodApi vodApi = new VodApi();
        System.out.println(vodApi.getVodsByLiveId(enterpriseid,token,"ff8080815d5ff09d015d645e89af05bf"));

    }

    @Test
    public void getMeetingRoomVodsByMeetingId() throws IOException {
        enterpriseid = "40260e9046bae2da238ac0b0c572326b91726a83";
        token = "91c648e1df1bfa9d9c879c408d7583dfb7c353cadf8e15ad64031fe9a8cde098";
        VodApi vodApi = new VodApi();
        System.out.println(vodApi.getMeetingRoomVodsByMeetingId(enterpriseid,token,"987987","101-bj1-txdevSig1-1157408035799",0,20));

    }

    @Test
    public void getEnterpriseVodsPage() throws IOException {
        enterpriseid = "40260e9046bae2da238ac0b0c572326b91726a83";
        token = "91c648e1df1bfa9d9c879c408d7583dfb7c353cadf8e15ad64031fe9a8cde098";
        VodApi vodApi = new VodApi();
        System.out.println(vodApi.getEnterpriseVodsPage(enterpriseid,token,1606120379000l,1606203460000l,0,20));

    }
}
